summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorBrad Smith <brad@cvs.openbsd.org>2006-06-11 00:31:58 +0000
committerBrad Smith <brad@cvs.openbsd.org>2006-06-11 00:31:58 +0000
commit8cb6f09a07ad7408b53135880e696fba61c1ff9b (patch)
tree0a6467765f21316579f90edc8bd9edbcb4b975aa
parentf97921c81bb13cc68787eaa34a35b40de9dc508a (diff)
the link state detection code should be checking for revision B2 instead
of B1 to account for the differences with the revision defines used in OpenBSD's if_bgereg.h vs FreeBSD's.
-rw-r--r--sys/dev/pci/if_bge.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/sys/dev/pci/if_bge.c b/sys/dev/pci/if_bge.c
index 71cbebd5d08..d7feb3c3c5a 100644
--- a/sys/dev/pci/if_bge.c
+++ b/sys/dev/pci/if_bge.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: if_bge.c,v 1.151 2006/06/02 05:58:24 beck Exp $ */
+/* $OpenBSD: if_bge.c,v 1.152 2006/06/11 00:31:57 brad Exp $ */
/*
* Copyright (c) 2001 Wind River Systems
@@ -2443,7 +2443,7 @@ bge_intr(void *xsc)
sc->bge_rdata->bge_status_block.bge_status = 0;
if ((BGE_ASICREV(sc->bge_chipid) == BGE_ASICREV_BCM5700 &&
- sc->bge_chipid != BGE_CHIPID_BCM5700_B1) ||
+ sc->bge_chipid != BGE_CHIPID_BCM5700_B2) ||
statusword & BGE_STATFLAG_LINKSTATE_CHANGED ||
sc->bge_link_evt)
bge_link_upd(sc);
@@ -3338,11 +3338,11 @@ bge_link_upd(struct bge_softc *sc)
* the interrupt handler.
*
* XXX: perhaps link state detection procedure used for
* BGE_CHIPID_BCM5700_B1 can be used for other BCM5700 revisions.
*/
if (BGE_ASICREV(sc->bge_chipid) == BGE_ASICREV_BCM5700 &&
- sc->bge_chipid != BGE_CHIPID_BCM5700_B1) {
+ sc->bge_chipid != BGE_CHIPID_BCM5700_B2) {
status = CSR_READ_4(sc, BGE_MAC_STS);
if (status & BGE_MACSTAT_MI_INTERRUPT) {
timeout_del(&sc->bge_timeout);
@@ -3338,11 +3338,11 @@ bge_link_upd(struct bge_softc *sc)
*
* XXX: perhaps link state detection procedure used for
- * BGE_CHIPID_BCM5700_B1 can be used for other BCM5700 revisions.
+ * BGE_CHIPID_BCM5700_B2 can be used for other BCM5700 revisions.
*/
if (BGE_ASICREV(sc->bge_chipid) == BGE_ASICREV_BCM5700 &&